@@ -31,15 +31,27 @@ tidy_lake_df <- function(lake){
   depth_col_pos <- grep("depth", names(res))
   depths <- res[,depth_col_pos]
 
-  has_meters <- grep("m", depths)
-  depths[has_meters] <- stringr::str_extract(depths[has_meters],
-                                             "(?<=\\().*\\sm")
-  depths[has_meters] <- sapply(depths[has_meters], function(x)
-                        substring(x, 1, nchar(x) - 2))
+  if(length(depths) > 0){
 
-  missing_meters <- which(!(1:length(depths) %in% has_meters))
+    has_meters <- grep("m", depths)
+    is_meters_first <- stringr::str_locate(depths[has_meters], "m")[1] <
+                       stringr::str_locate(depths[has_meters], "ft")[1]
 
-  res[,depth_col_pos] <- depths
+    if(is_meters_first){
+      depths[has_meters] <- stringr::str_extract(depths[has_meters],
+                                                 "(?<=).*\\sm")
+    }else{
+      depths[has_meters] <- stringr::str_extract(depths[has_meters],
+                                                 "(?<=\\().*\\sm")
+      }
+
+    depths[has_meters] <- sapply(depths[has_meters], function(x)
+                          substring(x, 1, nchar(x) - 2))
+
+    missing_meters <- which(!(1:length(depths) %in% has_meters))
+
+    res[,depth_col_pos] <- depths
+  }
 
   res
 }
